// $Id: ICMPEncoding.java,v 1.3 2001/05/27 21:15:21 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * ICMP protocol encoding information.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.3 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/27 21:15:21 $
 */
public class ICMPEncoding
{
  /**
   * ICMPPacket factory.
   */
  public static ICMPPacket create(int lLen, byte [] bytes) {
    String msa = EthernetEncoding.extractMACAddress(lLen, true, bytes); 
    String mda = EthernetEncoding.extractMACAddress(lLen, false, bytes); 

    String sa = IPEncoding.extractAddress(true, lLen, bytes);
    String da = IPEncoding.extractAddress(false, lLen, bytes);

    int icmpMessageCode = ICMPEncoding.extractICMPMessageCode(lLen, bytes);

    return new ICMPPacket(lLen, bytes, msa, mda, sa, da, icmpMessageCode);
  }

  /**
   * Extract the ICMP message code from packet data. The packet data 
   * must contain an ICMP header.
   * @param llen the length of the link-level header.
   * @param packetBytes packet bytes, including the link-layer and IP headers.
   * @return the ICMP message code. i.e. 0x08 signifies echo request.
   */
  public static int extractICMPMessageCode(int lLen, byte [] packetBytes) {
    return packetBytes[lLen + CODE_POS];
  }


  /**
   * Position of the ICMP message type within the icmp header.
   */
  private final static int CODE_POS = IPEncoding.HEADER_LEN;

  /**
   * Length in bytes of an ICMP header.
   */
  public final static int HEADER_LEN = 4;

  private String _rcsid = 
    "$Id: ICMPEncoding.java,v 1.3 2001/05/27 21:15:21 pcharles Exp $";
}
